==> hqsoft_core-0.0.18.tar.gz: lib/core_base/widget_calendar_filter/calendar_popup_filter_widget.dart <==
import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/value_base/value_base.dart';

class CalendarPopupFilterWidget extends StatefulWidget {
  final DateTime minimumDate;
  final DateTime maximumDate;
  final bool barrierDismissible;
  final DateTime initialStartDate;
  final DateTime initialEndDate;
  final Function(DateTime, DateTime) onApplyClick;
  final Function onCancelClick;

  const CalendarPopupFilterWidget(
      {Key key,
      this.initialStartDate,
      this.initialEndDate,
      this.onApplyClick,
      this.onCancelClick,
      this.barrierDismissible = true,
      this.minimumDate,
      this.maximumDate})
      : super(key: key);

  @override
  _CalendarPopupFilterWidgetState createState() =>
      _CalendarPopupFilterWidgetState();
}

class _CalendarPopupFilterWidgetState extends State<CalendarPopupFilterWidget> {
  DateTime get _initialStartDate => widget.initialStartDate;

  DateTime get _initialEndDate => widget.initialEndDate;
  DateTime startDate;
  DateTime endDate;

  @override
  void initState() {
    super.initState();
    startDate = _initialStartDate;
    endDate = _initialEndDate;
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Scaffold(
        backgroundColor: Colors.transparent,
        body: InkWell(
          splashColor: Colors.transparent,
          focusColor: Colors.transparent,
          highlightColor: Colors.transparent,
          hoverColor: Colors.transparent,
          onTap: () {
            if (widget.barrierDismissible) Navigator.pop(context);
          },
          child: Center(
            child: SingleChildScrollView(
              child: Column(
                children: <Widget>[
                  Padding(
                    padding: const EdgeInsets.only(left: 5, right: 5),
                    child: Container(
                      decoration: BoxDecoration(
                        color: Colors.white,
                        borderRadius: BorderRadius.only(
                          topLeft: const Radius.circular(24.0),
                          topRight: const Radius.circular(24.0),
                        ),
                        boxShadow: <BoxShadow>[
                          BoxShadow(
                              color: Colors.grey.withOpacity(0.2),
                              offset: Offset(4, 4),
                              blurRadius: 8.0),
                        ],
                      ),
                      child: InkWell(
                        borderRadius: BorderRadius.all(Radius.circular(24.0)),
                        onTap: () {},
                        child: Column(
                          mainAxisAlignment: MainAxisAlignment.center,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisSize: MainAxisSize.min,
                          children: <Widget>[
                            Container(
                              padding: EdgeInsets.only(
                                  bottom: ScreenConfig.getWidthPx(8),
                                  top: ScreenConfig.getWidthPx(8)),
                              decoration: BoxDecoration(
                                color: colorPrimary,
                                borderRadius: BorderRadius.only(
                                  topLeft: const Radius.circular(24.0),
                                  topRight: const Radius.circular(24.0),
                                ),
                                boxShadow: <BoxShadow>[
                                  BoxShadow(
                                    color: Colors.grey.withOpacity(0.6),
                                    blurRadius: 8,
                                    offset: Offset(4, 4),
                                  ),
                                ],
                              ),
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.center,
                                crossAxisAlignment: CrossAxisAlignment.center,
                                children: <Widget>[
                                  Text(
                                    allTranslations.text("sys_from_date"),
                                    style: ThemeBase.textWhiteBoldFontSize14,
                                  ),
                                  SizedBox(
                                    width: 4,
                                  ),
                                  Text(
                                    startDate != null
                                        ? DateHelper.getStringJsonFormatPicker(
                                            startDate)
                                        : DateHelper.getStringJsonFormatPicker(
                                            widget.initialStartDate),
                                    style: ThemeBase.textWhiteBoldFontSize14,
                                  ),
                                ],
                              ),
                            ),
                            CustomCalendarFilterView(
                              minimumDate: widget.minimumDate,
                              maximumDate: widget.maximumDate,
                              initialSelectDate: widget.initialStartDate,
                              startEndDateChange: (DateTime selectDateData) {
                                setState(() {
                                  startDate = selectDateData;
                                });
                              },
                            ),
                            Container(
                              padding: EdgeInsets.only(
                                  bottom: ScreenConfig.getWidthPx(8),
                                  top: ScreenConfig.getWidthPx(8)),
                              decoration: BoxDecoration(
                                color: colorPrimary,
                                borderRadius:
                                    BorderRadius.all(Radius.circular(0.0)),
                                boxShadow: <BoxShadow>[
                                  BoxShadow(
                                    color: Colors.grey.withOpacity(0.6),
                                    blurRadius: 8,
                                    offset: Offset(4, 4),
                                  ),
                                ],
                              ),
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.center,
                                crossAxisAlignment: CrossAxisAlignment.center,
                                children: <Widget>[
                                  Text(
                                    allTranslations.text("sys_to_date"),
                                    style: ThemeBase.textWhiteBoldFontSize14,
                                  ),
                                  SizedBox(
                                    width: ScreenConfig.getWidthPx(4),
                                  ),
                                  Text(
                                    endDate != null
                                        ? DateHelper.getStringJsonFormatPicker(
                                            endDate)
                                        : DateHelper.getStringJsonFormatPicker(
                                            widget.initialEndDate),
                                    style: ThemeBase.textWhiteBoldFontSize14,
                                  ),
                                ],
                              ),
                            ),
                            CustomCalendarFilterView(
                              minimumDate: widget.minimumDate,
                              maximumDate: widget.maximumDate,
                              initialSelectDate: widget.initialEndDate,
                              startEndDateChange: (DateTime selectDateData) {
                                setState(() {
                                  endDate = selectDateData;
                                });
                              },
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),

                  //Button Yes
                  Padding(
                    padding: const EdgeInsets.only(left: 5, right: 5),
                    child: Container(
                      decoration: BoxDecoration(
                        color: Colors.white,
                        borderRadius: BorderRadius.only(
                          bottomLeft: const Radius.circular(24.0),
                          bottomRight: const Radius.circular(24.0),
                        ),
                      ),
                      child: Padding(
                        padding: EdgeInsets.only(
                            left: ScreenConfig.getWidthPx(8),
                            right: ScreenConfig.getWidthPx(8),
                            bottom: ScreenConfig.getWidthPx(4),
                            top: ScreenConfig.getWidthPx(2)),
                        child: Container(
                          height: ScreenConfig.getWidthPx(40),
                          decoration: BoxDecoration(
                            color: colorPrimary,
                            borderRadius:
                                BorderRadius.all(Radius.circular(24.0)),
                            boxShadow: <BoxShadow>[
                              BoxShadow(
                                color: Colors.grey.withOpacity(0.6),
                                blurRadius: 8,
                                offset: Offset(4, 4),
                              ),
                            ],
                          ),
                          child: Material(
                            color: Colors.transparent,
                            child: InkWell(
                              borderRadius:
                                  BorderRadius.all(Radius.circular(24.0)),
                              highlightColor: Colors.transparent,
                              onTap: () {
                                try {
                                  if (endDate.isBefore(startDate)) {
                                    AlertCustomize.showAlertOneButtonClose(
                                        context: context,
                                        messages: allTranslations
                                                .text("mess_sys_form_date") +
                                            DateHelper
                                                .getStringJsonFormatPicker(
                                                    startDate) +
                                            allTranslations
                                                .text("mess_sys_to_date_over") +
                                            DateHelper
                                                .getStringJsonFormatPicker(
                                                    endDate));
                                  } else {
                                    widget.onApplyClick(startDate, endDate);
                                    Navigator.pop(context);
                                  }
                                } catch (e) {}
                              },
                              child: Center(
                                child: Text(
                                  allTranslations.text("sys_yes"),
                                  style: ThemeBase.textButton,
                                ),
                              ),
                            ),
                          ),
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> hqsoft_core-0.0.83.tar.gz: lib/core_base/widget_calendar_filter/calendar_popup_filter_widget.dart <==
import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/value_base/value_base.dart';

class CalendarPopupFilterWidget extends StatefulWidget {
  final DateTime? minimumDate;
  final DateTime? maximumDate;
  final bool barrierDismissible;
  final DateTime? initialStartDate;
  final DateTime? initialEndDate;
  final Function(DateTime, DateTime)? onApplyClick;
  final Function? onCancelClick;

  const CalendarPopupFilterWidget(
      {
      this.initialStartDate,
      this.initialEndDate,
      this.onApplyClick,
      this.onCancelClick,
      this.barrierDismissible = true,
      this.minimumDate,
      this.maximumDate})
      ;

  @override
  _CalendarPopupFilterWidgetState createState() =>
      _CalendarPopupFilterWidgetState();
}

class _CalendarPopupFilterWidgetState extends State<CalendarPopupFilterWidget> {
  DateTime? get _initialStartDate => widget.initialStartDate;

  DateTime? get _initialEndDate => widget.initialEndDate;
  DateTime? startDate;
  DateTime? endDate;

  @override
  void initState() {
    super.initState();
    startDate = _initialStartDate;
    endDate = _initialEndDate;
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Scaffold(
        backgroundColor: Colors.transparent,
        body: InkWell(
          splashColor: Colors.transparent,
          focusColor: Colors.transparent,
          highlightColor: Colors.transparent,
          hoverColor: Colors.transparent,
          onTap: () {
            if (widget.barrierDismissible) Navigator.pop(context);
          },
          child: Center(
            child: SingleChildScrollView(
              child: Column(
                children: <Widget>[
                  Padding(
                    padding: const EdgeInsets.only(left: 5, right: 5),
                    child: Container(
                      decoration: BoxDecoration(
                        color: Colors.white,
                        borderRadius: BorderRadius.only(
                          topLeft: const Radius.circular(24.0),
                          topRight: const Radius.circular(24.0),
                        ),
                        boxShadow: <BoxShadow>[
                          BoxShadow(
                              color: Colors.grey.withOpacity(0.2),
                              offset: Offset(4, 4),
                              blurRadius: 8.0),
                        ],
                      ),
                      child: InkWell(
                        borderRadius: BorderRadius.all(Radius.circular(24.0)),
                        onTap: () {},
                        child: Column(
                          mainAxisAlignment: MainAxisAlignment.center,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisSize: MainAxisSize.min,
                          children: <Widget>[
                            Container(
                              padding: EdgeInsets.only(
                                  bottom: ScreenConfig.getWidthPx(8),
                                  top: ScreenConfig.getWidthPx(8)),
                              decoration: BoxDecoration(
                                color: colorPrimary,
                                borderRadius: BorderRadius.only(
                                  topLeft: const Radius.circular(24.0),
                                  topRight: const Radius.circular(24.0),
                                ),
                                boxShadow: <BoxShadow>[
                                  BoxShadow(
                                    color: Colors.grey.withOpacity(0.6),
                                    blurRadius: 8,
                                    offset: Offset(4, 4),
                                  ),
                                ],
                              ),
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.center,
                                crossAxisAlignment: CrossAxisAlignment.center,
                                children: <Widget>[
                                  Text(
                                    allTranslations.text("sys_from_date"),
                                    style: ThemeBase.textWhiteBoldFontSize14,
                                  ),
                                  SizedBox(
                                    width: 4,
                                  ),
                                  Text(
                                    startDate != null
                                        ? DateHelper.getStringJsonFormatPicker(
                                            startDate!)
                                        : DateHelper.getStringJsonFormatPicker(
                                            widget.initialStartDate!),
                                    style: ThemeBase.textWhiteBoldFontSize14,
                                  ),
                                ],
                              ),
                            ),
                            CustomCalendarFilterView(
                              minimumDate: widget.minimumDate as DateTime,
                              maximumDate: widget.maximumDate as DateTime,
                              initialSelectDate: widget.initialStartDate as DateTime,
                              startEndDateChange: (DateTime selectDateData) {
                                setState(() {
                                  startDate = selectDateData;
                                });
                              },
                            ),
                            Container(
                              padding: EdgeInsets.only(
                                  bottom: ScreenConfig.getWidthPx(8),
                                  top: ScreenConfig.getWidthPx(8)),
                              decoration: BoxDecoration(
                                color: colorPrimary,
                                borderRadius:
                                    BorderRadius.all(Radius.circular(0.0)),
                                boxShadow: <BoxShadow>[
                                  BoxShadow(
                                    color: Colors.grey.withOpacity(0.6),
                                    blurRadius: 8,
                                    offset: Offset(4, 4),
                                  ),
                                ],
                              ),
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.center,
                                crossAxisAlignment: CrossAxisAlignment.center,
                                children: <Widget>[
                                  Text(
                                    allTranslations.text("sys_to_date"),
                                    style: ThemeBase.textWhiteBoldFontSize14,
                                  ),
                                  SizedBox(
                                    width: ScreenConfig.getWidthPx(4),
                                  ),
                                  Text(
                                    endDate != null
                                        ? DateHelper.getStringJsonFormatPicker(
                                            endDate!)
                                        : DateHelper.getStringJsonFormatPicker(
                                            widget.initialEndDate!),
                                    style: ThemeBase.textWhiteBoldFontSize14,
                                  ),
                                ],
                              ),
                            ),
                            CustomCalendarFilterView(
                              minimumDate: widget.minimumDate as DateTime,
                              maximumDate: widget.maximumDate as DateTime,
                              initialSelectDate: widget.initialEndDate as DateTime,
                              startEndDateChange: (DateTime selectDateData) {
                                setState(() {
                                  endDate = selectDateData;
                                });
                              },
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),

                  //Button Yes
                  Padding(
                    padding: const EdgeInsets.only(left: 5, right: 5),
                    child: Container(
                      decoration: BoxDecoration(
                        color: Colors.white,
                        borderRadius: BorderRadius.only(
                          bottomLeft: const Radius.circular(24.0),
                          bottomRight: const Radius.circular(24.0),
                        ),
                      ),
                      child: Padding(
                        padding: EdgeInsets.only(
                            left: ScreenConfig.getWidthPx(8),
                            right: ScreenConfig.getWidthPx(8),
                            bottom: ScreenConfig.getWidthPx(4),
                            top: ScreenConfig.getWidthPx(2)),
                        child: Container(
                          height: ScreenConfig.getWidthPx(40),
                          decoration: BoxDecoration(
                            color: colorPrimary,
                            borderRadius:
                                BorderRadius.all(Radius.circular(24.0)),
                            boxShadow: <BoxShadow>[
                              BoxShadow(
                                color: Colors.grey.withOpacity(0.6),
                                blurRadius: 8,
                                offset: Offset(4, 4),
                              ),
                            ],
                          ),
                          child: Material(
                            color: Colors.transparent,
                            child: InkWell(
                              borderRadius:
                                  BorderRadius.all(Radius.circular(24.0)),
                              highlightColor: Colors.transparent,
                              onTap: () {
                                try {
                                  if (endDate!.isBefore(startDate!)) {
                                    AlertCustomize.showAlertOneButtonClose(
                                        context: context,
                                        messages: allTranslations
                                                .text("mess_sys_form_date") +
                                            DateHelper
                                                .getStringJsonFormatPicker(
                                                    startDate!) +
                                            allTranslations
                                                .text("mess_sys_to_date_over") +
                                            DateHelper
                                                .getStringJsonFormatPicker(
                                                    endDate!));
                                  } else {
                                    widget.onApplyClick!(startDate!, endDate!);
                                    Navigator.pop(context);
                                  }
                                } catch (e) {}
                              },
                              child: Center(
                                child: Text(
                                  allTranslations.text("sys_yes"),
                                  style: ThemeBase.textButton,
                                ),
                              ),
                            ),
                          ),
                        ),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }
}
